@@ -80,58 +80,56 @@ def spimx(word,model,words_list1,words_list2):
     nltk.download('punkt',quiet=True)
 
     def preprocess_text(text):
-        # Convert to lowercase
+            # Convert to lowercase
         text = text.lower()
-        # Remove special characters and numbers
+            # Remove special characters and numbers
         text = re.sub(r'[^a-z]+', ' ', text)
-        # Tokenize the text
+            # Tokenize the text
         words = word_tokenize(text)
-        # Remove stopwords
+            # Remove stopwords
         stop_words = set(stopwords.words('english'))
         words = [word for word in words if word not in stop_words]
-        # Stem the words
+            # Stem the words
         stemmer = PorterStemmer()
         words = [stemmer.stem(word) for word in words]
         return words
 
-    def load_data(words_list1,words_list2):
-        # Open the CSV file
+    def load_data(words_list1, words_list2):
+            # Open the CSV file
 
-            input_data = words_list1
-            label_data = words_list2
+        input_data = words_list1
+        label_data = words_list2
             # Iterate through each row
 
-            return input_data, label_data
+        return input_data, label_data
 
     def get_similarity(word, words_list):
-        # Preprocess the input word
-        word = preprocess_text(word)
-        # Initialize a list to store the similarity scores
-        similarity_scores = []
-        # Iterate through each word in the words list
-        for w in words_list:
-            # Preprocess the word in the words list
-            w = preprocess_text(w)
-            # Calculate the similarity score between the two words
-            if len(set(word).union(w)) == 0:
-                score = random.randint(0,20)
-            else:
-                score = len(set(word).intersection(w)) / len(set(word).union(w))
+            # Preprocess the input word
+         word = preprocess_text(word)
+            # Initialize a list to store the similarity scores
+         similarity_scores = []
+            # Iterate through each word in the words list
+         for w in words_list:
+                # Preprocess the word in the words list
+             w_processed = preprocess_text(w)
+                # Calculate the similarity score between the two words
+             if len(set(w_processed).union(w)) == 0:
+                 score = random.randint(0, 20)
+             else:
+                 score = len(set(word).intersection(w_processed)) / len(set(word).union(w_processed))
 
+             similarity_scores.append(score)
+            # Return the index of the most similar word
+             return similarity_scores.index(max(similarity_scores))
 
-            similarity_scores.append(score)
-        # Return the index of the most similar word
-        return similarity_scores.index(max(similarity_scores))
+            # Load the data from the CSV file
 
-
-        # Load the data from the CSV file
-
-    input_data, label_data = load_data(words_list1,words_list2)
-    # Get the user input
+    input_data, label_data = load_data(words_list1, words_list2)
+        # Get the user input
     input_word = word
-    # Find the index of the most similar word in the input data
+        # Find the index of the most similar word in the input data
     index = get_similarity(input_word, input_data)
-    # Output the corresponding label from the label data
+        # Output the corresponding label from the label data
     return label_data[index]
 
 def rasv(word,model,words_list1,words_list2):
@@ -148,7 +146,35 @@ def rasv(word,model,words_list1,words_list2):
             index = words_list1.index(similar_word)
             return words_list2[index]
         else:
-            return "No output in dataset for this input"
+            return "Sorry , I don't know that"
+            #from googlesearch import search
+            #import requests
+            #from bs4 import BeautifulSoup
+
+            # Take input from user
+
+            #query = input_word
+            # Search for the query on Google and get the first website
+            #search_results = search(query)
+            #first_website = next(iter(search_results))
+
+            # Request the first website's content and parse it using BeautifulSoup
+            #response = requests.get(first_website)
+            #soup = BeautifulSoup(response.content, "html.parser")
+
+            # Extract the first four lines of text from the website's content (without HTML tags)
+            #text_lines = []
+            #for p_tag in soup.find_all('\n'):
+             #   stripped_line = p_tag.get_text().strip()
+              #  if stripped_line:
+               #     text_lines.append(stripped_line)
+                #    if len(text_lines) == 50:
+                 #       break
+
+            # Print the first four lines of text (without HTML tags)
+           # a = "\n".join(text_lines)
+            #return a
+
 
 
 
@@ -236,81 +262,80 @@ def generate_pycode(text):
                 parts = line.split("if")[1].strip().split("is")
                 variable_name = parts[0].strip()
                 variable_value = parts[1].strip()
-                code += f"{' ' * 4 * indent_level}if {variable_name} = {variable_value}\n"
+                code += f"{' ' * 4 * indent_level}if {variable_name} == {variable_value}\n"
                 indent_level += 1
             else:
                 code += f"{' ' * 4 * indent_level}if {line.split('if')[1].strip()}:\n"
                 indent_level += 1
         elif "else" in line:
             # generate else statement
-            indent_level -= 1
+
             code += f"{' ' * 4 * indent_level}else:\n"
             indent_level += 1
         elif "otherwise" in line:
             # generate else statement
-            indent_level -= 1
+
             code += f"{' ' * 4 * indent_level}else:\n"
             indent_level += 1
-
         elif "elif" in line:
             # generate elif statement
             if "is not" in line:
-                indent_level -= 1
+
                 parts = line.split("elif")[1].strip().split("is not")
                 variable_name = parts[0].strip()
                 variable_value = parts[1].strip()
                 code += f"{' ' * 4 * indent_level}elif {variable_name} != {variable_value}\n"
                 indent_level += 1
             elif "is" in line:
-                indent_level -= 1
+
                 parts = line.split("elif")[1].strip().split("is")
                 variable_name = parts[0].strip()
                 variable_value = parts[1].strip()
-                code += f"{' ' * 4 * indent_level}elif {variable_name} = {variable_value}\n"
+                code += f"{' ' * 4 * indent_level}elif {variable_name} == {variable_value}\n"
                 indent_level += 1
             else:
-                indent_level -= 1
-                code += f"{' ' * 4 * indent_level}elif {line.split('elif')[1].strip()}:\n"
                 indent_level += 1
+                code += f"{' ' * 4 * indent_level}elif {line.split('elif')[1].strip()}:\n"
+
 
         elif "also if" in line:
             # generate elif statement
             if "is not" in line:
-                indent_level -= 1
+
                 parts = line.split("also if")[1].strip().split("is not")
                 variable_name = parts[0].strip()
                 variable_value = parts[1].strip()
                 code += f"{' ' * 4 * indent_level}elif {variable_name} != {variable_value}\n"
                 indent_level += 1
             elif "is" in line:
-                indent_level -= 1
+
                 parts = line.split("also if")[1].strip().split("is")
                 variable_name = parts[0].strip()
                 variable_value = parts[1].strip()
-                code += f"{' ' * 4 * indent_level}elif {variable_name} = {variable_value}\n"
+                code += f"{' ' * 4 * indent_level}elif {variable_name} == {variable_value}\n"
                 indent_level += 1
             else:
-                indent_level -= 1
+
                 code += f"{' ' * 4 * indent_level}elif {line.split('elif')[1].strip()}:\n"
                 indent_level += 1
         elif "else if" in line:
             # generate elif statement
             if "is not" in line:
-                indent_level -= 1
+
                 parts = line.split("else if")[1].strip().split("is not")
                 variable_name = parts[0].strip()
                 variable_value = parts[1].strip()
                 code += f"{' ' * 4 * indent_level}elif {variable_name} != {variable_value}\n"
                 indent_level += 1
             elif "is" in line:
-                indent_level -= 1
+
                 parts = line.split("else if")[1].strip().split("is")
                 variable_name = parts[0].strip()
                 variable_value = parts[1].strip()
-                code += f"{' ' * 4 * indent_level}elif {variable_name} = {variable_value}\n"
+                code += f"{' ' * 4 * indent_level}elif {variable_name} == {variable_value}\n"
                 indent_level += 1
             else:
-                indent_level -= 1
+
                 code += f"{' ' * 4 * indent_level}elif {line.split('elif')[1].strip()}:\n"
                 indent_level += 1
         elif "end" in line:
@@ -479,10 +504,30 @@ def generate_js_code(text):
         else:
             code += "Error 2: Writer unable to convert this text to code."
     return code
+def pywriter(text,filepath,input,label):
+    filename = open(filepath, 'r')
+    file = csv.DictReader(filename)
+    global py_list1
+    global py_list2
+    py_list1 = []
+    py_list2= []
+    # creating dictreader object
+    for col in file:
+        py_list1.append(col[input])
+        py_list2.append(col[label])
+    closest_index = -1
+    closest_distance = float("inf")
+    for i, w in enumerate(py_list1):
+        distance = abs(len(text) - len(w))
+        if distance < closest_distance:
+            closest_index = i
+            closest_distance = distance
+        x = py_list2[closest_index]
+    return generate_pycode(x)
 def codewriter(language,text,model):
     nameerror(model,"codewriter()")
     if language=="python":
-        code = generate_pycode(text)
+        code = generate_pycode(text) # pywriter(text,"code.csv","in","out")
         return code
     elif language=="php":
         code = generate_phpcode(text)
@@ -509,7 +554,7 @@ def model_load(modeltype,input, model):
     if modeltype == "spim":
         return spim(input,model,words_list1,words_list2)
     elif modeltype == "spimx":
-        return spimx(input,model,words_list1,words_list2)
+        return spimx(input, model, words_list1, words_list2)
     elif modeltype == "rasv":
         return rasv(input,model,words_list1,words_list2)
     elif modeltype == "spimxr":
